# pyella-rs

[![PyPI](https://img.shields.io/pypi/v/pyella-rs?style=for-the-badge)](https://pypi.org/project/pyella-rs/)
![PyPI - License](https://img.shields.io/pypi/l/pyella-rs?style=for-the-badge)

Python bindings for the ella datastore.

## Installation

You can install `pyella-rs` from PyPI using pip:

```shell
python -m pip install pyella-rs
```

